==> e107-0.7.20.tbz: www/e107/e107_languages/English/lan_ren_help.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_languages/English/lan_ren_help.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/
define("LANHELP_1", "Black");
define("LANHELP_2", "Blue");
define("LANHELP_3", "Brown");
define("LANHELP_4", "Cyan");
define("LANHELP_5", "Dark Blue");
define("LANHELP_6", "Dark Red");
define("LANHELP_7", "Green");
define("LANHELP_8", "Indigo");
define("LANHELP_9", "Olive");
define("LANHELP_10", "Orange");
define("LANHELP_11", "Red");
define("LANHELP_12", "Violet");
define("LANHELP_13", "White");
define("LANHELP_14", "Yellow");

define("LANHELP_15", "Tiny");
define("LANHELP_16", "Small");
define("LANHELP_17", "Normal");
define("LANHELP_18", "Large");
define("LANHELP_19", "Larger");
define("LANHELP_20", "Massive");

define("LANHELP_21", "Click to open color dialog ...");
define("LANHELP_22", "Click to open size dialog ...");

define("LANHELP_23", "Insert link: [link]http://mysite.com[/link] or  [link=http://yoursite.com]Visit My Site[/link]");
define("LANHELP_24", "Bold text: [b]This text will be bold[/b]", "font-weight:bold; width: 20px");
define("LANHELP_25", "Italic text: [i]This text will be italicised[/i]", "font-style:italic; width: 20px");
define("LANHELP_26", "Underline text: [u]This text will be underlined[/u]", "text-decoration: underline; width: 20px");
define("LANHELP_27", "Insert image: [img]mypicture.jpg[/img]");
define("LANHELP_28", "Center align: [center]This text will be centered[/center]");
define("LANHELP_29", "Left align: [left]This text will be left aligned[/left]");
define("LANHELP_30", "Right align: [right]This text will be right aligned[/right]");
define("LANHELP_31", "Blockquote text: [blockquote]This text will be blockquoted (indented)[/blockquote]");
define("LANHELP_32", "Code - preformatted text: [code]\$foo = bah;[/code]");
define("LANHELP_33", "HTML - removes linebreaks from text: [html]&lt;table&gt;&lt;tr&gt;&lt;td&gt; etc[/html]");
define("LANHELP_34", "[newpage] or [newpage=title] Insert newpage tag, splits article into more than one page");
define("LANHELP_35", "hyperlink url");
define("LANHELP_36", "Unordered: [list]line1*line2*line3[/list] Ordered: [list=type]line1*line2*line3[/list]");

define("LANHELP_37", "Insert image from e107_images/newspost_images/ directory");
define("LANHELP_38", "link to full image will be generated");

define("LANHELP_39", "Insert download link from existing downloads");
define("LANHELP_40", "There are currently no existing downloads");

define("LANHELP_41", "Font Size...");
define("LANHELP_42", "Select Image...");
define("LANHELP_43", "Select Download File...");
define("LANHELP_44", "Click to open/close emoticon dialog ...");
define("LANHELP_45", "Insert image from directory: ");
define("LANHELP_46", "* No files found in: ");

define("LANHELP_47", "Insert flash: [flash=width,height]http://www.example.com/file.swf[/flash]");
?>

==> e107-1.0.3.tbz: www/e107/e107_languages/English/lan_ren_help.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_languages/English/lan_ren_help.php $
|     $Revision: 11801 $
|     $Id: lan_ren_help.php 11801 2010-09-18 21:22:29Z e107steved $
|     $Author: e107steved $
+----------------------------------------------------------------------------+
*/
define("LANHELP_1", "Black");
define("LANHELP_2", "Blue");
define("LANHELP_3", "Brown");
define("LANHELP_4", "Cyan");
define("LANHELP_5", "Dark Blue");
define("LANHELP_6", "Dark Red");
define("LANHELP_7", "Green");
define("LANHELP_8", "Indigo");
define("LANHELP_9", "Olive");
define("LANHELP_10", "Orange");
define("LANHELP_11", "Red");
define("LANHELP_12", "Violet");
define("LANHELP_13", "White");
define("LANHELP_14", "Yellow");

define("LANHELP_15", "Tiny");
define("LANHELP_16", "Small");
define("LANHELP_17", "Normal");
define("LANHELP_18", "Large");
define("LANHELP_19", "Larger");
define("LANHELP_20", "Massive");

define("LANHELP_21", "Click to open color dialog ...");
define("LANHELP_22", "Click to open size dialog ...");

define("LANHELP_23", "Insert link: [link]http://mysite.com[/link] or  [link=http://yoursite.com]Visit My Site[/link]");
define("LANHELP_24", "Bold text: [b]This text will be bold[/b]", "font-weight:bold; width: 20px");
define("LANHELP_25", "Italic text: [i]This text will be italicised[/i]", "font-style:italic; width: 20px");
define("LANHELP_26", "Underline text: [u]This text will be underlined[/u]", "text-decoration: underline; width: 20px");
define("LANHELP_27", "Insert image: [img]mypicture.jpg[/img]");
define("LANHELP_28", "Center align: [center]This text will be centered[/center]");
define("LANHELP_29", "Left align: [left]This text will be left aligned[/left]");
define("LANHELP_30", "Right align: [right]This text will be right aligned[/right]");
define("LANHELP_31", "Blockquote text: [blockquote]This text will be blockquoted (indented)[/blockquote]");
define("LANHELP_32", "Code - preformatted text: [code]\$foo = bah;[/code]");
define("LANHELP_33", "HTML - removes linebreaks from text: [html]&lt;table&gt;&lt;tr&gt;&lt;td&gt; etc[/html]");
define("LANHELP_34", "[newpage] or [newpage=title] Insert newpage tag, splits article into more than one page");
define("LANHELP_35", "hyperlink url");
define("LANHELP_36", "Unordered: [list]line1*line2*line3[/list] Ordered: [list=type]line1*line2*line3[/list]");

define("LANHELP_37", "Insert image from e107_images/newspost_images/ directory");
define("LANHELP_38", "link to full image will be generated");

define("LANHELP_39", "Insert download link from existing downloads");
define("LANHELP_40", "There are currently no existing downloads");

define("LANHELP_41", "Font Size...");
define("LANHELP_42", "Select Image...");
define("LANHELP_43", "Select Download File...");
define("LANHELP_44", "Click to open/close emoticon dialog ...");
define("LANHELP_45", "Insert image from directory: ");
define("LANHELP_46", "* No files found in: ");

define("LANHELP_47", "Insert flash: [flash=width,height]http://www.example.com/file.swf[/flash]");
// 0.7.23
define("LANHELP_48", "YouTube video: [youtube=tiny|small|medium|big|huge|width,height]6kYjxJmk0wc[/youtube]");
// 0.7.24
define("LANHELP_49", "Justify align: [justify]This text will be justified[/justify]");

?>
